import{d,o as r,c as o,w as a,b as c,Z as f,u as s,df as u,ez as i,eC as l,bS as p}from"./vue-router.2a09679a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ad7a82bf-3b28-4313-9829-2c71c7cddd78",e._sentryDebugIdIdentifier="sentry-dbid-ad7a82bf-3b28-4313-9829-2c71c7cddd78")}catch{}})();const _=d({__name:"AbstraButton",setup(e){return(t,n)=>(r(),o(s(p),i(l(t.$attrs)),{default:a(()=>[c(s(u),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:a(()=>[f(t.$slots,"default")]),_:3})]),_:3},16))}});export{_};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang.b88154c2.js.map
