import{_}from"./Login.vue_vue_type_script_setup_true_lang.c4ed5aa3.js";import{b as m,u as f}from"./workspaceStore.09087956.js";import{d as l,eq as b,ed as y,X as g,b as w,u,o as k,$ as h}from"./vue-router.2a09679a.js";import"./Logo.4bfdee2e.js";import"./CircularLoading.7699468a.js";import"./index.90bdaa5c.js";import"./url.fd4f4aec.js";import"./colorHelpers.23e83093.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="9c57db13-5c47-4f18-96d2-7379d6057663",e._sentryDebugIdIdentifier="sentry-dbid-9c57db13-5c47-4f18-96d2-7379d6057663")}catch{}})();const v={class:"runner"},I=l({__name:"Login",setup(e){const o=b(),r=y(),i=m(),n=f(),p=async()=>{await i.signUp();const{redirect:t,...s}=r.query;if(t){await o.push({path:t,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(t,s)=>{var a,d,c;return k(),g("div",v,[w(_,{"logo-url":(d=(a=u(n).state.workspace)==null?void 0:a.logoUrl)!=null?d:void 0,"brand-name":(c=u(n).state.workspace)==null?void 0:c.brandName,onDone:p},null,8,["logo-url","brand-name"])])}}});const N=h(I,[["__scopeId","data-v-907be835"]]);export{N as default};
//# sourceMappingURL=Login.7382c2f5.js.map
