import{S as d,dC as a,dD as i}from"./vue-router.2a09679a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="1d24e868-e0c3-4784-8289-c75138b1d62f",e._sentryDebugIdIdentifier="sentry-dbid-1d24e868-e0c3-4784-8289-c75138b1d62f")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:o,RangePicker:c}=a(i),y=d(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:c,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(c.name,c),e.component(r.name,r),e.component(t.name,t),e.component(o.name,o),e)});export{y as D,r as M,o as Q,c as R,t as W};
//# sourceMappingURL=dayjs.280c40ad.js.map
