import{O as r}from"./workspaceStore.09087956.js";import{d as l,W as i,X as u,b as a,w as o,u as n,o as c,aF as d,db as f,da as b}from"./vue-router.2a09679a.js";import"./url.fd4f4aec.js";import"./colorHelpers.23e83093.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="fc525dbd-8a4b-4415-a1d7-64e196576301",e._sentryDebugIdIdentifier="sentry-dbid-fc525dbd-8a4b-4415-a1d7-64e196576301")}catch{}})();const w=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new r().logoutCallback()}),(t,s)=>(c(),u("div",null,[a(n(f),null,{default:o(()=>[d("You're authenticated")]),_:1}),a(n(b),null,{default:o(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.8fdb2047.js.map
