import{P as k}from"./api.1c5cfb07.js";import{b as _}from"./workspaceStore.09087956.js";import{d as w,L as g,N as b,e as v,X as h,b as r,w as T,u as e,c as p,R as m,o as s,$ as K}from"./vue-router.2a09679a.js";import{K as R,_ as I,W as P,P as S,b as V}from"./WorkflowView.a4acbf5e.js";import{A as d,T as x}from"./TabPane.bbbaa995.js";import"./Card.9e59e121.js";import"./fetch.0c05edc9.js";import"./metadata.e3d75875.js";import"./PhBug.vue.272a3e93.js";import"./PhCheckCircle.vue.bbecc176.js";import"./PhKanban.vue.549a3ee3.js";import"./PhWebhooksLogo.vue.718bf526.js";import"./url.fd4f4aec.js";import"./colorHelpers.23e83093.js";import"./polling.33063483.js";import"./asyncComputed.1e9d0abf.js";import"./PhQuestion.vue.4cd30614.js";import"./ant-design.e55e1bbe.js";import"./index.b153c6c8.js";import"./index.0e0ca2be.js";import"./index.7d2c60ba.js";import"./CollapsePanel.cc4f4f35.js";import"./index.a1e30a9e.js";import"./index.2bc8c913.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.1aca0e04.js";import"./Workflow.744bcaf7.js";import"./validations.d23506bb.js";import"./string.6792602f.js";import"./uuid.0bbf11fd.js";import"./index.4445038d.js";import"./workspaces.0d4bb72c.js";import"./record.1f9cddba.js";import"./index.78d61239.js";import"./Badge.09e3ee92.js";import"./LoadingOutlined.4136294d.js";import"./DeleteOutlined.7c4710e4.js";import"./PhDownloadSimple.vue.d33f3e03.js";import"./utils.2ac115d2.js";import"./LoadingContainer.c638438c.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="2cefc0fd-0152-44dd-9eb9-a53a07c02b86",t._sentryDebugIdIdentifier="sentry-dbid-2cefc0fd-0152-44dd-9eb9-a53a07c02b86")}catch{}})();const W={class:"threads-view"},A=w({__name:"Threads",setup(t){const a=_().authHeaders,c=new k(a),i=new S(a),u=new V(a),y=new g(b.array(b.string()),"kanban-selected-stages"),o=v("kanban");return(B,l)=>(s(),h("div",W,[r(e(x),{activeKey:o.value,"onUpdate:activeKey":l[0]||(l[0]=f=>o.value=f)},{default:T(()=>[r(e(d),{key:"kanban",tab:"Kanban View"}),r(e(d),{key:"table",tab:"Table View"}),r(e(d),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),o.value==="kanban"?(s(),p(R,{key:0,"kanban-repository":e(i),"kanban-stages-storage":e(y),"stage-run-repository":e(u)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):m("",!0),o.value==="table"?(s(),p(I,{key:1,"kanban-repository":e(i)},null,8,["kanban-repository"])):m("",!0),o.value==="workflow"?(s(),p(P,{key:2,"kanban-repository":e(i),"workflow-api":e(c)},null,8,["kanban-repository","workflow-api"])):m("",!0)]))}});const ge=K(A,[["__scopeId","data-v-d2894db4"]]);export{ge as default};
//# sourceMappingURL=Threads.f3a1f5e9.js.map
