import{C as g}from"./CrudView.5c576934.js";import{a as l}from"./ant-design.e55e1bbe.js";import{a as b}from"./asyncComputed.1e9d0abf.js";import{d as w,ed as _,eq as h,f as I,c as k,u as v,o as x,er as C}from"./vue-router.2a09679a.js";import{a as z}from"./gateway.b08a6336.js";import{M as n}from"./member.53ae5da8.js";import"./tables.adb160d4.js";import"./router.c5972afe.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.b6793306.js";import"./BookOutlined.b0ead745.js";import"./url.fd4f4aec.js";import"./PhDotsThreeVertical.vue.1b4932cb.js";import"./index.b153c6c8.js";import"./popupNotifcation.ed0bf79d.js";import"./record.1f9cddba.js";import"./string.6792602f.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[a]="447420ab-a2cb-4649-8593-f324f6ce7a66",o._sentryDebugIdIdentifier="sentry-dbid-447420ab-a2cb-4649-8593-f324f6ce7a66")}catch{}})();const K=w({__name:"Editors",setup(o){const a=_(),s=h(),r=a.params.organizationId,m=[{key:"email",label:"Email"}],d=async e=>{await n.create(r,e.email),c()};async function u(e){var t;if(((t=z.getAuthor())==null?void 0:t.claims.email)===e.email&&await l("You are about to remove your own access. You won't be able to access this organization anymore. Are you sure?")){await n.delete(r,e.authorId),await s.push({name:"organizations"});return}await l("Are you sure you want to remove this member's access?")&&(await n.delete(r,e.authorId),c())}const{loading:f,result:p,refetch:c}=b(()=>n.list(r)),y=I(()=>{var e,i;return{columns:[{name:"Email",align:"left"},{name:"Role"},{name:"",align:"right"}],rows:(i=(e=p.value)==null?void 0:e.map(t=>({key:t.email,cells:[{type:"text",text:t.email},{type:"text",text:t.role},{type:"actions",actions:[{icon:C,label:"Remove access",onClick:()=>u(t),dangerous:!0}]}]})))!=null?i:[]}});return(e,i)=>(x(),k(g,{"entity-name":"editors",loading:v(f),title:"Organization editors",description:"List all organization editors.","empty-title":"No editors yet",table:y.value,"create-button-text":"Add editors",fields:m,onCreate:d},null,8,["loading","table"]))}});export{K as default};
//# sourceMappingURL=Editors.36a0f678.js.map
