import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.a29d9cad.js";import{d as i,ed as s,c as m,u as d,o as a}from"./vue-router.2a09679a.js";import"./gateway.b08a6336.js";import"./popupNotifcation.ed0bf79d.js";import"./fetch.0c05edc9.js";import"./record.1f9cddba.js";import"./SaveButton.b7f2e2dd.js";import"./UnsavedChangesHandler.fdad812d.js";import"./ExclamationCircleOutlined.caa1c4dd.js";import"./CrudView.5c576934.js";import"./router.c5972afe.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.b6793306.js";import"./BookOutlined.b0ead745.js";import"./url.fd4f4aec.js";import"./PhDotsThreeVertical.vue.1b4932cb.js";import"./index.b153c6c8.js";import"./PhRocketLaunch.vue.c82a4e99.js";import"./asyncComputed.1e9d0abf.js";import"./polling.33063483.js";import"./PhPencil.vue.6b4fe7f8.js";import"./index.90bdaa5c.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="2f985952-171e-4264-b74c-038cd35d483d",o._sentryDebugIdIdentifier="sentry-dbid-2f985952-171e-4264-b74c-038cd35d483d")}catch{}})();const z=i({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new p(e);return(c,f)=>(a(),m(n,{"env-var-repository":d(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars.a67935f8.js.map
