import{i as g}from"./metadata.e3d75875.js";import{W as h}from"./Watermark.c01a78cf.js";import{F as k}from"./PhArrowSquareOut.vue.e47ec562.js";import{d as w,eq as b,f as x,u as e,X as m,b as o,w as r,R as v,o as s,c as d,aF as f,d7 as u,aR as C,ee as D,df as _,ef as I,ec as F,$ as T}from"./vue-router.2a09679a.js";import{u as z}from"./workspaceStore.09087956.js";import"./index.8fa4696e.js";import{C as B}from"./Card.9e59e121.js";import"./PhBug.vue.272a3e93.js";import"./PhCheckCircle.vue.bbecc176.js";import"./PhKanban.vue.549a3ee3.js";import"./PhWebhooksLogo.vue.718bf526.js";import"./url.fd4f4aec.js";import"./colorHelpers.23e83093.js";import"./TabPane.bbbaa995.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="470d1e03-d216-469d-8411-950d004007e8",t._sentryDebugIdIdentifier="sentry-dbid-470d1e03-d216-469d-8411-950d004007e8")}catch{}})();const H={key:0,class:"home-container"},N=w({__name:"Home",setup(t){const n=b(),i=z(),p=x(()=>{var a;return((a=i.state.workspace)==null?void 0:a.sidebar.filter(l=>l.id!=="home"))||[]}),y=a=>{n.push({path:`/${a}`})};return(a,l)=>e(i).state.workspace?(s(),m("div",H,[o(e(_),{vertical:"",gap:"large",class:"cards-container"},{default:r(()=>[p.value.length===0?(s(),d(e(u),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[f(" There are no forms available for you. ")]),_:1})):(s(!0),m(C,{key:1},D(p.value,c=>(s(),d(e(B),{key:c.id,class:"form-card",onClick:R=>y(c.path)},{default:r(()=>[o(e(_),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[(s(),d(I(e(g)(c.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),o(e(u),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[f(F(c.name),1)]),_:2},1024),o(e(k),{size:"20"})]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1}),o(h,{class:"watermark","page-id":"home",locale:e(i).state.workspace.language},null,8,["locale"])])):v("",!0)}});const M=T(N,[["__scopeId","data-v-a0bfe546"]]);export{M as default};
//# sourceMappingURL=Home.2d018072.js.map
