import{E as d}from"./api.1c5cfb07.js";import{C as w}from"./ContentLayout.a6c9e47a.js";import{d as c,L as g,N as l,e as _,c as a,w as u,o as i,b as n,u as o,R as s}from"./vue-router.2a09679a.js";import{K as v,_ as K,W as R,E,a as T}from"./WorkflowView.a4acbf5e.js";import{A as p,T as V}from"./TabPane.bbbaa995.js";import"./fetch.0c05edc9.js";import"./metadata.e3d75875.js";import"./PhBug.vue.272a3e93.js";import"./PhCheckCircle.vue.bbecc176.js";import"./PhKanban.vue.549a3ee3.js";import"./PhWebhooksLogo.vue.718bf526.js";import"./polling.33063483.js";import"./asyncComputed.1e9d0abf.js";import"./PhQuestion.vue.4cd30614.js";import"./ant-design.e55e1bbe.js";import"./index.b153c6c8.js";import"./index.0e0ca2be.js";import"./index.7d2c60ba.js";import"./CollapsePanel.cc4f4f35.js";import"./index.a1e30a9e.js";import"./index.2bc8c913.js";import"./isNumeric.75337b1e.js";import"./PhArrowCounterClockwise.vue.1aca0e04.js";import"./Workflow.744bcaf7.js";import"./validations.d23506bb.js";import"./string.6792602f.js";import"./uuid.0bbf11fd.js";import"./index.4445038d.js";import"./workspaces.0d4bb72c.js";import"./workspaceStore.09087956.js";import"./url.fd4f4aec.js";import"./colorHelpers.23e83093.js";import"./record.1f9cddba.js";import"./index.78d61239.js";import"./Badge.09e3ee92.js";import"./Card.9e59e121.js";import"./LoadingOutlined.4136294d.js";import"./DeleteOutlined.7c4710e4.js";import"./PhDownloadSimple.vue.d33f3e03.js";import"./utils.2ac115d2.js";import"./LoadingContainer.c638438c.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="659c0734-a2a7-4360-b904-e2407044b83e",r._sentryDebugIdIdentifier="sentry-dbid-659c0734-a2a7-4360-b904-e2407044b83e")}catch{}})();const yo=c({__name:"WorkflowThreads",setup(r){const t=new E,m=new T,f=new g(l.array(l.string()),"kanban-selected-stages"),k=new d,e=_("kanban");return(W,b)=>(i(),a(w,{"full-width":""},{default:u(()=>[n(o(V),{activeKey:e.value,"onUpdate:activeKey":b[0]||(b[0]=y=>e.value=y)},{default:u(()=>[n(o(p),{key:"kanban",tab:"Kanban View"}),n(o(p),{key:"table",tab:"Table View"}),n(o(p),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),e.value==="kanban"?(i(),a(v,{key:0,"kanban-repository":o(t),"kanban-stages-storage":o(f),"stage-run-repository":o(m)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):s("",!0),e.value==="table"?(i(),a(K,{key:1,"kanban-repository":o(t)},null,8,["kanban-repository"])):s("",!0),e.value==="workflow"?(i(),a(R,{key:2,"kanban-repository":o(t),"workflow-api":o(k)},null,8,["kanban-repository","workflow-api"])):s("",!0)]),_:1}))}});export{yo as default};
//# sourceMappingURL=WorkflowThreads.ef557630.js.map
