import{k as n,T as a,m as r,P as o,C as c,M as f,s as d,n as s,p,q as m,t as u,v as b}from"./vue-router.2a09679a.js";import{s as g,c as y,a as i}from"./workspaceStore.09087956.js";import{_ as l}from"./App.vue_vue_type_style_index_0_lang.b863be83.js";import"./url.fd4f4aec.js";import"./colorHelpers.23e83093.js";import"./PlayerConfigProvider.fb1068fd.js";import"./index.4445038d.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="b0c3fdfc-fe7a-4bc0-8fe2-2b8b4f71f5c7",t._sentryDebugIdIdentifier="sentry-dbid-b0c3fdfc-fe7a-4bc0-8fe2-2b8b4f71f5c7")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await g();const t=y(),e=n({render:()=>p(l)});a.init(),r(e,i),w.init(),e.use(i),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",c),e.component("Markdown",f),e.component("Message",d),s(e,m),s(e,u),s(e,b)})();
//# sourceMappingURL=player.32da739e.js.map
