import{d as p,f as l,X as n,a as o,aR as r,ee as f,R as d,o as a,ea as _,ec as i,$ as u}from"./vue-router.2a09679a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="64503162-f3b2-4968-8615-ffe8eff05b22",e._sentryDebugIdIdentifier="sentry-dbid-64503162-f3b2-4968-8615-ffe8eff05b22")}catch{}})();const m={key:0,class:"p-steps p-component"},y={class:"p-steps-list"},b={class:"p-menuitem-link"},g={class:"p-steps-number"},I=p({__name:"Steps",props:{stepsInfo:{type:Object,default:null}},setup(e){const s=e,c=l(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",to:""})):[]);return(h,k)=>e.stepsInfo?(a(),n("nav",m,[o("ol",y,[(a(!0),n(r,null,f(c.value,(v,t)=>(a(),n("li",{key:t,class:_(["p-steps-item",{"p-highlight":t+1===e.stepsInfo.current}])},[o("span",b,[o("span",g,i(t+1),1)])],2))),128))])])):d("",!0)}});const D=u(I,[["__scopeId","data-v-c916ecf3"]]);export{D as S};
//# sourceMappingURL=Steps.ac5a26fb.js.map
