import{d as t,o as d,X as o,b as s,u as c,bx as r,$ as _}from"./vue-router.2a09679a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="fddd9ca0-c20c-4407-abe4-e2a03e4c8bc6",e._sentryDebugIdIdentifier="sentry-dbid-fddd9ca0-c20c-4407-abe4-e2a03e4c8bc6")}catch{}})();const i={class:"centered"},f=t({__name:"LoadingContainer",setup(e){return(n,a)=>(d(),o("div",i,[s(c(r))]))}});const u=_(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.c638438c.js.map
