import{P as _}from"./PlayerNavbar.1edc7147.js";import{u as m,i as l}from"./workspaceStore.09087956.js";import{d as f,eq as h,ed as r,f as g,r as y,X as b,u as a,c as k,R as v,a as w,b as L,o as s,$ as I}from"./vue-router.2a09679a.js";import"./metadata.e3d75875.js";import"./PhBug.vue.272a3e93.js";import"./PhCheckCircle.vue.bbecc176.js";import"./PhKanban.vue.549a3ee3.js";import"./PhWebhooksLogo.vue.718bf526.js";import"./PhSignOut.vue.aaa2624c.js";import"./index.2ec31d33.js";import"./Avatar.98f1e3cf.js";import"./url.fd4f4aec.js";import"./colorHelpers.23e83093.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="a85387fc-eac3-4332-a1b1-97c1723cf2c9",t._sentryDebugIdIdentifier="sentry-dbid-a85387fc-eac3-4332-a1b1-97c1723cf2c9")}catch{}})();const N={class:"main-container"},C={class:"content"},R=f({__name:"Main",setup(t){const e=h(),o=m(),c=r().path,i=({path:n})=>{e.push({path:`/${n}`})},p=()=>{e.push({name:"playerLogin"})},u=g(()=>!!r().meta.hideLogin);return l(()=>e.push({name:"playerLogin"})),(n,V)=>{const d=y("RouterView");return s(),b("div",N,[a(o).state.workspace?(s(),k(_,{key:0,"current-path":a(c),"hide-login":u.value,"runner-data":a(o).state.workspace,onNavigate:i,onLoginClick:p},null,8,["current-path","hide-login","runner-data"])):v("",!0),w("section",C,[L(d)])])}}});const A=I(R,[["__scopeId","data-v-aeaee359"]]);export{A as default};
//# sourceMappingURL=Main.53fa3465.js.map
