import{d as i,c as p,w as n,o as m,b as s,u as e}from"./vue-router.2a09679a.js";import"./editor.332e7814.js";import{W as a}from"./workspaces.0d4bb72c.js";import{C as d}from"./ContentLayout.a6c9e47a.js";import{_ as c,E as f}from"./View.vue_vue_type_script_setup_true_lang.a29d9cad.js";import"./workspaceStore.09087956.js";import"./url.fd4f4aec.js";import"./colorHelpers.23e83093.js";import"./asyncComputed.1e9d0abf.js";import"./record.1f9cddba.js";import"./gateway.b08a6336.js";import"./popupNotifcation.ed0bf79d.js";import"./fetch.0c05edc9.js";import"./SaveButton.b7f2e2dd.js";import"./UnsavedChangesHandler.fdad812d.js";import"./ExclamationCircleOutlined.caa1c4dd.js";import"./CrudView.5c576934.js";import"./router.c5972afe.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.b6793306.js";import"./BookOutlined.b0ead745.js";import"./PhDotsThreeVertical.vue.1b4932cb.js";import"./index.b153c6c8.js";import"./PhRocketLaunch.vue.c82a4e99.js";import"./polling.33063483.js";import"./PhPencil.vue.6b4fe7f8.js";import"./index.90bdaa5c.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="e9c373c8-18ee-4c71-8e46-45411602529c",o._sentryDebugIdIdentifier="sentry-dbid-e9c373c8-18ee-4c71-8e46-45411602529c")}catch{}})();const F=i({__name:"EnvVarsEditor",setup(o){const r=new f;return(t,u)=>(m(),p(d,null,{default:n(()=>[s(c,{"env-var-repository":e(r),mode:"editor","file-opender":e(a)},null,8,["env-var-repository","file-opender"])]),_:1}))}});export{F as default};
//# sourceMappingURL=EnvVarsEditor.9374a45a.js.map
