import"./vue-router.2a09679a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="f1b2b0bd-7960-46f5-9138-efbf101ee2de",e._sentryDebugIdIdentifier="sentry-dbid-f1b2b0bd-7960-46f5-9138-efbf101ee2de")}catch{}})();function d(e){return e.charAt(0).toUpperCase()+e.slice(1)}function f(e,r,a=!1,t=!0,n=!1){const s=(t?e.toLocaleLowerCase():e).normalize("NFD").replace(/[\u0300-\u036f]/g,""),c=n?s.replace(/[^a-zA-Z0-9/]/g,"_"):s.replace(/[^a-zA-Z0-9]/g,"_"),l=a?c:c.replace(/_+/g,"_");return r?l:l.replace(/_$/,"")}function u(e){var o;const a=e.toLocaleLowerCase().trim().normalize("NFD").replace(/[\u0300-\u036f]/g,""),t=/[a-z0-9]+/g,n=a.match(t);return(o=n==null?void 0:n.join("-"))!=null?o:""}function g(e){try{return{valid:!0,parsed:JSON.parse(e)}}catch(r){return{valid:!1,message:r instanceof Error?r.message:"Unknown error"}}}export{u as a,d as c,f as n,g as v};
//# sourceMappingURL=string.6792602f.js.map
