import{O as r}from"./workspaceStore.09087956.js";import{d as i,W as l,X as c,b as a,w as n,u as o,o as f,aF as d,db as u,da as _}from"./vue-router.2a09679a.js";import"./url.fd4f4aec.js";import"./colorHelpers.23e83093.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="a759cffd-d1f9-4e3f-a270-984268372c6c",e._sentryDebugIdIdentifier="sentry-dbid-a759cffd-d1f9-4e3f-a270-984268372c6c")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new r().loginCallback()}),(t,s)=>(f(),c("div",null,[a(o(u),null,{default:n(()=>[d("You're authenticated")]),_:1}),a(o(_),null,{default:n(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.6fbd3944.js.map
