import{d as n,X as s,a,Z as d,ea as r,o as c,$ as l}from"./vue-router.2a09679a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="449218b8-8ceb-483b-bf4e-eb69ec225c91",e._sentryDebugIdIdentifier="sentry-dbid-449218b8-8ceb-483b-bf4e-eb69ec225c91")}catch{}})();const _={class:"content-layout"},u=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(c(),s("div",_,[a("div",{class:r(["centered-layout",{"full-width":t.fullWidth}])},[d(t.$slots,"default",{},void 0,!0)],2)]))}});const f=l(u,[["__scopeId","data-v-6397d501"]]);export{f as C};
//# sourceMappingURL=ContentLayout.a6c9e47a.js.map
