import{eN as t,eO as r}from"./vue-router.2a09679a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="15e38eca-6662-4ae6-930c-63ae8036606e",e._sentryDebugIdIdentifier="sentry-dbid-15e38eca-6662-4ae6-930c-63ae8036606e")}catch{}})();function s(e,n){return t(1,arguments),r(e,Date.now(),n)}export{s as f};
//# sourceMappingURL=index.0e0ca2be.js.map
